@@ -21,7 +21,7 @@ package org.apache.flink.connector.jdbc.table;
 import org.apache.flink.connector.jdbc.JdbcDataTestBase;
 import org.apache.flink.connector.jdbc.JdbcTestFixture;
 import org.apache.flink.connector.jdbc.dialect.JdbcDialect;
-import org.apache.flink.connector.jdbc.internal.options.JdbcConnectorOptions;
+import org.apache.flink.connector.jdbc.internal.options.InternalJdbcConnectionOptions;
 import org.apache.flink.connector.jdbc.split.JdbcGenericParameterValuesProvider;
 import org.apache.flink.connector.jdbc.split.JdbcNumericBetweenParametersProvider;
 import org.apache.flink.connector.jdbc.split.JdbcParameterValuesProvider;
@@ -42,7 +42,6 @@ import java.io.Serializable;
 import java.sql.ResultSet;
 import java.util.Arrays;
 
-import static org.apache.flink.connector.jdbc.JdbcTestFixture.DERBY_EBOOKSHOP_DB;
 import static org.apache.flink.connector.jdbc.JdbcTestFixture.INPUT_TABLE;
 import static org.apache.flink.connector.jdbc.JdbcTestFixture.SELECT_ALL_BOOKS;
 import static org.apache.flink.connector.jdbc.JdbcTestFixture.SELECT_ALL_BOOKS_SPLIT_BY_AUTHOR;
@@ -66,8 +65,8 @@ class JdbcRowDataInputFormatTest extends JdbcDataTestBase {
                 DataTypes.INT()
             };
     final JdbcDialect dialect =
-            JdbcConnectorOptions.builder()
-                    .setDBUrl(DERBY_EBOOKSHOP_DB.getJdbcUrl())
+            InternalJdbcConnectionOptions.builder()
+                    .setDBUrl(getMetadata().getJdbcUrl())
                     .setTableName(INPUT_TABLE)
                     .build()
                     .getDialect();
@@ -93,8 +92,8 @@ class JdbcRowDataInputFormatTest extends JdbcDataTestBase {
                         () -> {
                             inputFormat =
                                     JdbcRowDataInputFormat.builder()
-                                            .setDrivername(DERBY_EBOOKSHOP_DB.getDriverClass())
-                                            .setDBUrl(DERBY_EBOOKSHOP_DB.getJdbcUrl())
+                                            .setDrivername(getMetadata().getDriverClass())
+                                            .setDBUrl(getMetadata().getJdbcUrl())
                                             .setQuery(SELECT_ALL_BOOKS)
                                             .build();
                             inputFormat.openInputFormat();
@@ -109,7 +108,7 @@ class JdbcRowDataInputFormatTest extends JdbcDataTestBase {
                             inputFormat =
                                     JdbcRowDataInputFormat.builder()
                                             .setDrivername("org.apache.derby.jdbc.idontexist")
-                                            .setDBUrl(DERBY_EBOOKSHOP_DB.getJdbcUrl())
+                                            .setDBUrl(getMetadata().getJdbcUrl())
                                             .setQuery(SELECT_ALL_BOOKS)
                                             .setRowConverter(dialect.getRowConverter(rowType))
                                             .build();
@@ -124,7 +123,7 @@ class JdbcRowDataInputFormatTest extends JdbcDataTestBase {
                         () -> {
                             inputFormat =
                                     JdbcRowDataInputFormat.builder()
-                                            .setDrivername(DERBY_EBOOKSHOP_DB.getDriverClass())
+                                            .setDrivername(getMetadata().getDriverClass())
                                             .setDBUrl("jdbc:der:iamanerror:mory:ebookshop")
                                             .setQuery(SELECT_ALL_BOOKS)
                                             .setRowConverter(dialect.getRowConverter(rowType))
@@ -140,8 +139,8 @@ class JdbcRowDataInputFormatTest extends JdbcDataTestBase {
                         () -> {
                             inputFormat =
                                     JdbcRowDataInputFormat.builder()
-                                            .setDrivername(DERBY_EBOOKSHOP_DB.getDriverClass())
-                                            .setDBUrl(DERBY_EBOOKSHOP_DB.getJdbcUrl())
+                                            .setDrivername(getMetadata().getDriverClass())
+                                            .setDBUrl(getMetadata().getJdbcUrl())
                                             .setQuery("iamnotsql")
                                             .setRowConverter(dialect.getRowConverter(rowType))
                                             .build();
@@ -156,8 +155,8 @@ class JdbcRowDataInputFormatTest extends JdbcDataTestBase {
                         () -> {
                             inputFormat =
                                     JdbcRowDataInputFormat.builder()
-                                            .setDrivername(DERBY_EBOOKSHOP_DB.getDriverClass())
-                                            .setDBUrl(DERBY_EBOOKSHOP_DB.getJdbcUrl())
+                                            .setDrivername(getMetadata().getDriverClass())
+                                            .setDBUrl(getMetadata().getJdbcUrl())
                                             .setRowConverter(dialect.getRowConverter(rowType))
                                             .build();
                         })
@@ -171,7 +170,7 @@ class JdbcRowDataInputFormatTest extends JdbcDataTestBase {
                         () -> {
                             inputFormat =
                                     JdbcRowDataInputFormat.builder()
-                                            .setDrivername(DERBY_EBOOKSHOP_DB.getDriverClass())
+                                            .setDrivername(getMetadata().getDriverClass())
                                             .setQuery(SELECT_ALL_BOOKS)
                                             .setRowConverter(dialect.getRowConverter(rowType))
                                             .build();
@@ -186,8 +185,8 @@ class JdbcRowDataInputFormatTest extends JdbcDataTestBase {
                         () -> {
                             inputFormat =
                                     JdbcRowDataInputFormat.builder()
-                                            .setDrivername(DERBY_EBOOKSHOP_DB.getDriverClass())
-                                            .setDBUrl(DERBY_EBOOKSHOP_DB.getJdbcUrl())
+                                            .setDrivername(getMetadata().getDriverClass())
+                                            .setDBUrl(getMetadata().getJdbcUrl())
                                             .setQuery(SELECT_ALL_BOOKS)
                                             .setFetchSize(-7)
                                             .build();
@@ -199,8 +198,8 @@ class JdbcRowDataInputFormatTest extends JdbcDataTestBase {
     void testValidFetchSizeIntegerMin() {
         inputFormat =
                 JdbcRowDataInputFormat.builder()
-                        .setDrivername(DERBY_EBOOKSHOP_DB.getDriverClass())
-                        .setDBUrl(DERBY_EBOOKSHOP_DB.getJdbcUrl())
+                        .setDrivername(getMetadata().getDriverClass())
+                        .setDBUrl(getMetadata().getJdbcUrl())
                         .setQuery(SELECT_ALL_BOOKS)
                         .setFetchSize(Integer.MIN_VALUE)
                         .setRowConverter(dialect.getRowConverter(rowType))
@@ -211,8 +210,8 @@ class JdbcRowDataInputFormatTest extends JdbcDataTestBase {
     void testJdbcInputFormatWithoutParallelism() throws IOException {
         inputFormat =
                 JdbcRowDataInputFormat.builder()
-                        .setDrivername(DERBY_EBOOKSHOP_DB.getDriverClass())
-                        .setDBUrl(DERBY_EBOOKSHOP_DB.getJdbcUrl())
+                        .setDrivername(getMetadata().getDriverClass())
+                        .setDBUrl(getMetadata().getJdbcUrl())
                         .setQuery(SELECT_ALL_BOOKS)
                         .setResultSetType(ResultSet.TYPE_SCROLL_INSENSITIVE)
                         .setRowConverter(dialect.getRowConverter(rowType))
@@ -244,8 +243,8 @@ class JdbcRowDataInputFormatTest extends JdbcDataTestBase {
                 new JdbcNumericBetweenParametersProvider(min, max).ofBatchSize(fetchSize);
         inputFormat =
                 JdbcRowDataInputFormat.builder()
-                        .setDrivername(DERBY_EBOOKSHOP_DB.getDriverClass())
-                        .setDBUrl(DERBY_EBOOKSHOP_DB.getJdbcUrl())
+                        .setDrivername(getMetadata().getDriverClass())
+                        .setDBUrl(getMetadata().getJdbcUrl())
                         .setQuery(SELECT_ALL_BOOKS_SPLIT_BY_ID)
                         .setParametersProvider(pramProvider)
                         .setResultSetType(ResultSet.TYPE_SCROLL_INSENSITIVE)
@@ -282,8 +281,8 @@ class JdbcRowDataInputFormatTest extends JdbcDataTestBase {
                 new JdbcNumericBetweenParametersProvider(min, max).ofBatchSize(fetchSize);
         inputFormat =
                 JdbcRowDataInputFormat.builder()
-                        .setDrivername(DERBY_EBOOKSHOP_DB.getDriverClass())
-                        .setDBUrl(DERBY_EBOOKSHOP_DB.getJdbcUrl())
+                        .setDrivername(getMetadata().getDriverClass())
+                        .setDBUrl(getMetadata().getJdbcUrl())
                         .setQuery(SELECT_ALL_BOOKS_SPLIT_BY_ID)
                         .setParametersProvider(pramProvider)
                         .setResultSetType(ResultSet.TYPE_SCROLL_INSENSITIVE)
@@ -320,8 +319,8 @@ class JdbcRowDataInputFormatTest extends JdbcDataTestBase {
                 new JdbcGenericParameterValuesProvider(queryParameters);
         inputFormat =
                 JdbcRowDataInputFormat.builder()
-                        .setDrivername(DERBY_EBOOKSHOP_DB.getDriverClass())
-                        .setDBUrl(DERBY_EBOOKSHOP_DB.getJdbcUrl())
+                        .setDrivername(getMetadata().getDriverClass())
+                        .setDBUrl(getMetadata().getJdbcUrl())
                         .setQuery(SELECT_ALL_BOOKS_SPLIT_BY_AUTHOR)
                         .setParametersProvider(paramProvider)
                         .setResultSetType(ResultSet.TYPE_SCROLL_INSENSITIVE)
@@ -362,8 +361,8 @@ class JdbcRowDataInputFormatTest extends JdbcDataTestBase {
     void testEmptyResults() throws IOException {
         inputFormat =
                 JdbcRowDataInputFormat.builder()
-                        .setDrivername(DERBY_EBOOKSHOP_DB.getDriverClass())
-                        .setDBUrl(DERBY_EBOOKSHOP_DB.getJdbcUrl())
+                        .setDrivername(getMetadata().getDriverClass())
+                        .setDBUrl(getMetadata().getJdbcUrl())
                         .setQuery(SELECT_EMPTY)
                         .setResultSetType(ResultSet.TYPE_SCROLL_INSENSITIVE)
                         .setRowConverter(dialect.getRowConverter(rowType))
